<?php
/**
 * Map API fields
 *
 * @package   WP Grid Builder - Map Facet
 * @author    Loïc Blascos
 * @copyright 2019-2021 Loïc Blascos
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

return [
	[
		'id'                => 'map_api_section',
		'tab'               => 'behaviour',
		'type'              => 'section',
		'title'             => __( 'API Type', 'wpgb-map-facet' ),
		'fields'            => [
			[
				'id'                => 'map_type',
				'type'              => 'radio',
				'label'             => __( 'Map API', 'wpgb-map-facet' ),
				'options'           => [
					'leaflet' => 'Leaflet',
					'mapbox'  => 'Mapbox',
					'google'  => 'Google',
				],
				'default'           => 'leaflet',
				'conditional_logic' => [
					'relation' => 'AND',
					[
						'field'   => 'filter_type',
						'compare' => '===',
						'value'   => 'map',
					],
				],
			],
			[
				'id'                => 'geo_type',
				'type'              => 'radio',
				'label'             => __( 'Geocoding API', 'wpgb-map-facet' ),
				'options'           => [
					'mapbox' => 'Mapbox',
					'google' => 'Google',
				],
				'default'           => 'mapbox',
				'conditional_logic' => [
					'relation' => 'AND',
					[
						'field'   => 'filter_type',
						'compare' => '===',
						'value'   => 'geolocation',
					],
				],
			],
			[
				'id'                => 'map_api_key',
				'type'              => 'password',
				'label'             => __( 'API Key', 'wpgb-map-facet' ),
				'width'             => 380,
				'conditional_logic' => [
					'relation' => 'OR',
					[
						[
							'field'   => 'filter_type',
							'compare' => '===',
							'value'   => 'map',
						],
						[
							'field'   => 'map_type',
							'compare' => '===',
							'value'   => 'google',
						],
					],
					[
						[
							'field'   => 'filter_type',
							'compare' => '===',
							'value'   => 'geolocation',
						],
						[
							'field'   => 'geo_type',
							'compare' => '===',
							'value'   => 'google',
						],
					],
				],
			],
			[
				'id'                => 'map_access_token',
				'type'              => 'password',
				'label'             => __( 'Access Token', 'wpgb-map-facet' ),
				'width'             => 380,
				'conditional_logic' => [
					'relation' => 'OR',
					[
						[
							'field'   => 'filter_type',
							'compare' => '===',
							'value'   => 'map',
						],
						[
							'field'   => 'map_type',
							'compare' => '===',
							'value'   => 'mapbox',
						],
					],
					[
						[
							'field'   => 'filter_type',
							'compare' => '===',
							'value'   => 'geolocation',
						],
						[
							'field'   => 'geo_type',
							'compare' => '===',
							'value'   => 'mapbox',
						],
					],
				],
			],
			[
				'id'                => 'map_limit_results',
				'type'              => 'select',
				'label'             => __( 'Map Results', 'wpgb-map-facet' ),
				'default'           => 'all',
				'width'             => 380,
				'options'           => [
					'all'  => __( 'Display all markers', 'wpgb-map-facet' ),
					'page' => __( 'Display markers in current page', 'wpgb-map-facet' ),
				],
				'conditional_logic' => [
					'relation' => 'AND',
					[
						'field'   => 'filter_type',
						'compare' => '===',
						'value'   => 'map',
					],
				],
			],
			[
				'id'                => 'map_filtering',
				'type'              => 'toggle',
				'label'             => __( 'Map Filtering', 'wpgb-map-facet' ),
				'conditional_logic' => [
					'relation' => 'AND',
					[
						'field'   => 'filter_type',
						'compare' => '===',
						'value'   => 'map',
					],
				],
			],
			[
				'id'                => 'geo_countries',
				'type'              => 'select',
				'label'             => __( 'Restrict Search to', 'wpgb-map-facet' ),
				'default'           => '',
				'width'             => 380,
				'multiple'          => true,
				'search'            => true,
				'placeholder'       => __( 'All countries', 'wpgb-map-facet' ),
				'tooltip'           => __( 'Google API is limited to 5 countries at maximum.', 'wpgb-map-facet' ),
				'options'           => [
					'AF' => 'Afghanistan',
					'AX' => '&#197;land Islands',
					'AL' => 'Albania',
					'DZ' => 'Algeria',
					'AS' => 'American Samoa',
					'AD' => 'Andorra',
					'AO' => 'Angola',
					'AI' => 'Anguilla',
					'AQ' => 'Antarctica',
					'AG' => 'Antigua and Barbuda',
					'AR' => 'Argentina',
					'AM' => 'Armenia',
					'AW' => 'Aruba',
					'AU' => 'Australia',
					'AT' => 'Austria',
					'AZ' => 'Azerbaijan',
					'BS' => 'Bahamas',
					'BH' => 'Bahrain',
					'BD' => 'Bangladesh',
					'BB' => 'Barbados',
					'BY' => 'Belarus',
					'BE' => 'Belgium',
					'PW' => 'Belau',
					'BZ' => 'Belize',
					'BJ' => 'Benin',
					'BM' => 'Bermuda',
					'BT' => 'Bhutan',
					'BO' => 'Bolivia',
					'BQ' => 'Bonaire, Saint Eustatius and Saba',
					'BA' => 'Bosnia and Herzegovina',
					'BW' => 'Botswana',
					'BV' => 'Bouvet Island',
					'BR' => 'Brazil',
					'IO' => 'British Indian Ocean Territory',
					'BN' => 'Brunei',
					'BG' => 'Bulgaria',
					'BF' => 'Burkina Faso',
					'BI' => 'Burundi',
					'KH' => 'Cambodia',
					'CM' => 'Cameroon',
					'CA' => 'Canada',
					'CV' => 'Cape Verde',
					'KY' => 'Cayman Islands',
					'CF' => 'Central African Republic',
					'TD' => 'Chad',
					'CL' => 'Chile',
					'CN' => 'China',
					'CX' => 'Christmas Island',
					'CC' => 'Cocos (Keeling) Islands',
					'CO' => 'Colombia',
					'KM' => 'Comoros',
					'CG' => 'Congo (Brazzaville)',
					'CD' => 'Congo (Kinshasa)',
					'CK' => 'Cook Islands',
					'CR' => 'Costa Rica',
					'HR' => 'Croatia',
					'CU' => 'Cuba',
					'CW' => 'Cura&ccedil;ao',
					'CY' => 'Cyprus',
					'CZ' => 'Czech Republic',
					'DK' => 'Denmark',
					'DJ' => 'Djibouti',
					'DM' => 'Dominica',
					'DO' => 'Dominican Republic',
					'EC' => 'Ecuador',
					'EG' => 'Egypt',
					'SV' => 'El Salvador',
					'GQ' => 'Equatorial Guinea',
					'ER' => 'Eritrea',
					'EE' => 'Estonia',
					'ET' => 'Ethiopia',
					'FK' => 'Falkland Islands',
					'FO' => 'Faroe Islands',
					'FJ' => 'Fiji',
					'FI' => 'Finland',
					'FR' => 'France',
					'GF' => 'French Guiana',
					'PF' => 'French Polynesia',
					'TF' => 'French Southern Territories',
					'GA' => 'Gabon',
					'GM' => 'Gambia',
					'GE' => 'Georgia',
					'DE' => 'Germany',
					'GH' => 'Ghana',
					'GI' => 'Gibraltar',
					'GR' => 'Greece',
					'GL' => 'Greenland',
					'GD' => 'Grenada',
					'GP' => 'Guadeloupe',
					'GU' => 'Guam',
					'GT' => 'Guatemala',
					'GG' => 'Guernsey',
					'GN' => 'Guinea',
					'GW' => 'Guinea-Bissau',
					'GY' => 'Guyana',
					'HT' => 'Haiti',
					'HM' => 'Heard Island and McDonald Islands',
					'HN' => 'Honduras',
					'HK' => 'Hong Kong',
					'HU' => 'Hungary',
					'IS' => 'Iceland',
					'IN' => 'India',
					'ID' => 'Indonesia',
					'IR' => 'Iran',
					'IQ' => 'Iraq',
					'IE' => 'Ireland',
					'IM' => 'Isle of Man',
					'IL' => 'Israel',
					'IT' => 'Italy',
					'CI' => 'Ivory Coast',
					'JM' => 'Jamaica',
					'JP' => 'Japan',
					'JE' => 'Jersey',
					'JO' => 'Jordan',
					'KZ' => 'Kazakhstan',
					'KE' => 'Kenya',
					'KI' => 'Kiribati',
					'KW' => 'Kuwait',
					'KG' => 'Kyrgyzstan',
					'LA' => 'Laos',
					'LV' => 'Latvia',
					'LB' => 'Lebanon',
					'LS' => 'Lesotho',
					'LR' => 'Liberia',
					'LY' => 'Libya',
					'LI' => 'Liechtenstein',
					'LT' => 'Lithuania',
					'LU' => 'Luxembourg',
					'MO' => 'Macao',
					'MK' => 'North Macedonia',
					'MG' => 'Madagascar',
					'MW' => 'Malawi',
					'MY' => 'Malaysia',
					'MV' => 'Maldives',
					'ML' => 'Mali',
					'MT' => 'Malta',
					'MH' => 'Marshall Islands',
					'MQ' => 'Martinique',
					'MR' => 'Mauritania',
					'MU' => 'Mauritius',
					'YT' => 'Mayotte',
					'MX' => 'Mexico',
					'FM' => 'Micronesia',
					'MD' => 'Moldova',
					'MC' => 'Monaco',
					'MN' => 'Mongolia',
					'ME' => 'Montenegro',
					'MS' => 'Montserrat',
					'MA' => 'Morocco',
					'MZ' => 'Mozambique',
					'MM' => 'Myanmar',
					'NA' => 'Namibia',
					'NR' => 'Nauru',
					'NP' => 'Nepal',
					'NL' => 'Netherlands',
					'NC' => 'New Caledonia',
					'NZ' => 'New Zealand',
					'NI' => 'Nicaragua',
					'NE' => 'Niger',
					'NG' => 'Nigeria',
					'NU' => 'Niue',
					'NF' => 'Norfolk Island',
					'MP' => 'Northern Mariana Islands',
					'KP' => 'North Korea',
					'NO' => 'Norway',
					'OM' => 'Oman',
					'PK' => 'Pakistan',
					'PS' => 'Palestinian Territory',
					'PA' => 'Panama',
					'PG' => 'Papua New Guinea',
					'PY' => 'Paraguay',
					'PE' => 'Peru',
					'PH' => 'Philippines',
					'PN' => 'Pitcairn',
					'PL' => 'Poland',
					'PT' => 'Portugal',
					'PR' => 'Puerto Rico',
					'QA' => 'Qatar',
					'RE' => 'Reunion',
					'RO' => 'Romania',
					'RU' => 'Russia',
					'RW' => 'Rwanda',
					'BL' => 'Saint Barth&eacute;lemy',
					'SH' => 'Saint Helena',
					'KN' => 'Saint Kitts and Nevis',
					'LC' => 'Saint Lucia',
					'MF' => 'Saint Martin (French part)',
					'SX' => 'Saint Martin (Dutch part)',
					'PM' => 'Saint Pierre and Miquelon',
					'VC' => 'Saint Vincent and the Grenadines',
					'SM' => 'San Marino',
					'ST' => 'S&atilde;o Tom&eacute; and Pr&iacute;ncipe',
					'SA' => 'Saudi Arabia',
					'SN' => 'Senegal',
					'RS' => 'Serbia',
					'SC' => 'Seychelles',
					'SL' => 'Sierra Leone',
					'SG' => 'Singapore',
					'SK' => 'Slovakia',
					'SI' => 'Slovenia',
					'SB' => 'Solomon Islands',
					'SO' => 'Somalia',
					'ZA' => 'South Africa',
					'GS' => 'South Georgia/Sandwich Islands',
					'KR' => 'South Korea',
					'SS' => 'South Sudan',
					'ES' => 'Spain',
					'LK' => 'Sri Lanka',
					'SD' => 'Sudan',
					'SR' => 'Suriname',
					'SJ' => 'Svalbard and Jan Mayen',
					'SZ' => 'Swaziland',
					'SE' => 'Sweden',
					'CH' => 'Switzerland',
					'SY' => 'Syria',
					'TW' => 'Taiwan',
					'TJ' => 'Tajikistan',
					'TZ' => 'Tanzania',
					'TH' => 'Thailand',
					'TL' => 'Timor-Leste',
					'TG' => 'Togo',
					'TK' => 'Tokelau',
					'TO' => 'Tonga',
					'TT' => 'Trinidad and Tobago',
					'TN' => 'Tunisia',
					'TR' => 'Turkey',
					'TM' => 'Turkmenistan',
					'TC' => 'Turks and Caicos Islands',
					'TV' => 'Tuvalu',
					'UG' => 'Uganda',
					'UA' => 'Ukraine',
					'AE' => 'United Arab Emirates',
					'GB' => 'United Kingdom (UK)',
					'US' => 'United States (US)',
					'UM' => 'United States (US) Minor Outlying Islands',
					'UY' => 'Uruguay',
					'UZ' => 'Uzbekistan',
					'VU' => 'Vanuatu',
					'VA' => 'Vatican',
					'VE' => 'Venezuela',
					'VN' => 'Vietnam',
					'VG' => 'Virgin Islands (British)',
					'VI' => 'Virgin Islands (US)',
					'WF' => 'Wallis and Futuna',
					'EH' => 'Western Sahara',
					'WS' => 'Samoa',
					'YE' => 'Yemen',
					'ZM' => 'Zambia',
					'ZW' => 'Zimbabwe',
				],
				'conditional_logic' => [
					'relation' => 'AND',
					[
						'field'   => 'filter_type',
						'compare' => '===',
						'value'   => 'geolocation',
					],
				],
			],
			[
				'id'                => 'geo_google_types',
				'type'              => 'select',
				'label'             => __( 'Places to Search', 'wpgb-map-facet' ),
				'default'           => '',
				'width'             => 380,
				'multiple'          => true,
				'search'            => true,
				'tooltip'           => __( 'Selected place types may appear as a top-level suggestions while searching.', 'wpgb-map-facet' ),
				'placeholder'       => __( 'All types', 'wpgb-map-facet' ),
				'options'           => [
					'geocode'       => __( 'Geocode', 'wpgb-map-facet' ),
					'address'       => __( 'Address', 'wpgb-map-facet' ),
					'establishment' => __( 'Establishment', 'wpgb-map-facet' ),
					'(regions)'     => __( 'Regions', 'wpgb-map-facet' ),
					'(cities)'      => __( 'Cities', 'wpgb-map-facet' ),
				],
				'conditional_logic' => [
					'relation' => 'AND',
					[
						'field'   => 'filter_type',
						'compare' => '===',
						'value'   => 'geolocation',
					],
					[
						'field'   => 'geo_type',
						'compare' => '===',
						'value'   => 'google',
					],
				],
			],
			[
				'id'                => 'geo_mapbox_types',
				'type'              => 'select',
				'label'             => __( 'Places to Search', 'wpgb-map-facet' ),
				'default'           => '',
				'width'             => 380,
				'multiple'          => true,
				'search'            => true,
				'tooltip'           => __( 'Selected place types may appear as a top-level suggestions while searching.', 'wpgb-map-facet' ),
				'placeholder'       => __( 'All types', 'wpgb-map-facet' ),
				'options'           => [
					'country'      => __( 'Country', 'wpgb-map-facet' ),
					'region'       => __( 'Region', 'wpgb-map-facet' ),
					'postcode'     => __( 'Postal Code', 'wpgb-map-facet' ),
					'district'     => __( 'District', 'wpgb-map-facet' ),
					'place'        => __( 'Place', 'wpgb-map-facet' ),
					'locality'     => __( 'Locality', 'wpgb-map-facet' ),
					'neighborhood' => __( 'Neighborhood', 'wpgb-map-facet' ),
					'address'      => __( 'Address', 'wpgb-map-facet' ),
					'poi'          => __( 'Points of Interest', 'wpgb-map-facet' ),
				],
				'conditional_logic' => [
					'relation' => 'AND',
					[
						'field'   => 'filter_type',
						'compare' => '===',
						'value'   => 'geolocation',
					],
					[
						'field'   => 'geo_type',
						'compare' => '===',
						'value'   => 'mapbox',
					],
				],
			],
		],
		'conditional_logic' => [
			'relation' => 'AND',
			[
				[
					'field'   => 'action',
					'compare' => '===',
					'value'   => 'filter',
				],
				[
					'field'   => 'filter_type',
					'compare' => 'IN',
					'value'   => [ 'map', 'geolocation' ],
				],
			],
		],
	],
];
